*********
Tutorials
*********

Below are some tutorials showing how to cleanly handle the more complicated 
circumstances that come up in real tests:

.. toctree::

    python_snippets
    optional_params
    exceptions
